@@ -366,10 +366,13 @@ resizer.onResize = function ()
 	if (resizer.currentMode == "small" || resizer.currentMode == "mobile")
 	{
 		$('#portal-column-one').masonry({columnWidth:189, gutterWidth:69, itemSelector:'.portletWrapper', isResizable:true, animate:false});
+		$('#portal-column-two').masonry({columnWidth:189, gutterWidth:69, itemSelector:'.portletWrapper', isResizable:true, animate:false});
+		
 	}
 	else
 	{
 		$('#portal-column-one').masonry( 'destroy' );
+		$('#portal-column-two').masonry( 'destroy' );
 	}
 }
 
